use strict;
use warnings;

use Test::More tests => 1;

BEGIN { require_ok( 'Syntax::Feature::QwComments' ); }

diag( "Testing Syntax::Feature::QwComments $Syntax::Feature::QwComments::VERSION" );
diag( "Using Perl $]" );

1;
